#!/bin/sh

# Copyright 2018 by Gero Treuner <gero@70t.de>
#
# This file is part of CAcert key/certificate management scripts (short
# form: "CAcert scripts").
#
# CAcert scripts are free software: You can redistribute it and/or
# modify it under the terms of the GNU Affero General Public License as
# published by the Free Software Foundation, either version 3 of the
# license, or (at your option) any later version.
#
# CAcert scripts are distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public
# License along with CAcert scripts.  If not, see
# <http://www.gnu.org/licenses/>.

if ! test -r "$1"
then
  echo 'ERROR: Workflow not specified, file does not exist or is not accessable.'
  echo "Path: $1"
  exit 1
fi

CONTROL_WORKFLOW=$(realpath "$1")
CONTROL_SCRIPT_DIR=$(dirname "$CONTROL_WORKFLOW")
export CONTROL_SCRIPT_DIR
CONTROL_WORKING_DIR=$(pwd)
#CONTROL_TEMP_DIR=$(mktemp -d -p .)
CONTROL_TEMP_DIR=$CONTROL_WORKING_DIR
export CONTROL_TEMP_DIR
CONTROL_DEBUG=

if test -n "$CONTROL_DEBUG"
then
  echo "WORKFLOW=$CONTROL_WORKFLOW"
  echo "SCRIPT_DIR=$CONTROL_SCRIPT_DIR"
  echo "WORKING_DIR=$CONTROL_WORKING_DIR"
  echo "TEMP_DIR=$CONTROL_TEMP_DIR"
fi

. "$CONTROL_SCRIPT_DIR/scripts/lib.sh"

run_task ()
{
  $LOCAL resultPath="$CONTROL_TEMP_DIR/result"
  #$LOCAL taskScript="$CONTROL_SCRIPT_DIR/tasks/${VAR_TASK%%(*}"
  $LOCAL taskScript="$CONTROL_SCRIPT_DIR/tasks/${VAR_TASK%%\(*}"
  $LOCAL taskTitle="$(grep '^# WF_TITLE: ' "$taskScript" | sed 's/^[^:]*: //')"

  #if test "${VAR_TASK#*(}" != 'hidden)'
  if test "${VAR_TASK#*\(}" != 'hidden)'
  then
    if test "$VAR_PAUSE" = true
    then
      echo
      echo "Task finished. Press ENTER to continue..."
      $LOCAL dummy
      read dummy
    fi
    VAR_PAUSE=true
  
    clear
    echo
    echo 'Running task'
    echo "$taskTitle"
    echo
  fi

  rm -f "$resultPath"
  set_inputs
  (cd "$CONTROL_TEMP_DIR"; "$taskScript")
  $LOCAL retval=$?
  if test $retval != 0
  then
    exit 1
  fi

  if test -r "$resultPath"
  then
    . "$resultPath"
    set_outputs
  fi

  
  resultPath=$(env | sed -n 's/^\(\(INPUT\|OUTPUT\)_.*\)=.*/\1/p')
  if test -n "$resultPath"
  then
    unset $resultPath
  fi
}

set_inputs ()
{
  VAR_CMD=$(sed -n "/^TASK $VAR_TASK/,/^TASK / { / --> / s/\([^ ].*[^ ]\) * -->  *\([^ ].*[^ ]\)/INPUT_\2=\"\$WF_\1\";export INPUT_\2/ p }" < "$CONTROL_WORKFLOW")
  if test -n "$CONTROL_DEBUG"
  then
    echo "INPUTS=$VAR_CMD"
  fi
  eval $VAR_CMD
}

set_outputs()
{
  VAR_CMD=$(sed -n "/^TASK $VAR_TASK/,/^TASK / { / <-- / s/\([^ ].*[^ ]\) * <--  *\([^ ].*[^ ]\)/WF_\1=\"\$OUTPUT_\2\"/ p }" < "$CONTROL_WORKFLOW")
  if test -n "$CONTROL_DEBUG"
  then
    echo "OUTPUTS=$VAR_CMD"
  fi
  eval $VAR_CMD
}

read_tasks ()
{
  VAR_TASKS=$(sed -n '/^TASK / { s/^TASK  *// ; p }' < "$CONTROL_WORKFLOW")
}

run_tasks ()
{
  for VAR_TASK in $VAR_TASKS
  do
    run_task
  done
}

read_tasks
run_tasks

echo
echo "All done."
