#!/bin/sh

# Copyright 2018 by Gero Treuner <gero@70t.de>
#
# This file is part of CAcert key/certificate management scripts (short
# form: "CAcert scripts").
#
# CAcert scripts are free software: You can redistribute it and/or
# modify it under the terms of the GNU Affero General Public License as
# published by the Free Software Foundation, either version 3 of the
# license, or (at your option) any later version.
#
# CAcert scripts are distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public
# License along with CAcert scripts.  If not, see
# <http://www.gnu.org/licenses/>.

# WF_TITLE: Create CSR (certificate signing request) from private/public key pair

# WF_INPUT: INPUT_HASH_ALGO    Hash algorithm (default: SHA512)
# WF_INPUT: INPUT_KEYFILE_PATH Path of the generated key file

# WF_OUTPUT: OUTPUT_CSRFILE_PATH   Path of the CSR file

set -e

. "$CONTROL_SCRIPT_DIR/scripts/lib.sh"

secure_stty

run_task ()
{
  echo
  echo "Input of passphrase to unlock the key is required."
  echo -n "Passphrase (keystrokes are not displayed): "
  stty -echo
  $LOCAL outFileName="${INPUT_KEYFILE_PATH%.*}.req"
  openssl req \
    -new \
    -$INPUT_HASH_ALGO \
    -out "$outFileName" -outform PEM \
    -passin stdin \
    -batch \
    -key "$INPUT_KEYFILE_PATH"
  $LOCAL retval=$?
  echo
  restore_stty
  if test $retval = 0
  then
    echo >"$CONTROL_TEMP_DIR/result" "OUTPUT_CSRFILE_PATH='$outFileName'"
  fi
  exit $retval
}

check_input ()
{
  if test -z "$INPUT_KEYFILE_PATH"
  then
    echo 'ERROR: No filename given. Input variable: INPUT_KEYFILE_PATH'
    VAR_EXIT=true
  fi
  if ! test -r "$INPUT_KEYFILE_PATH"
  then
    echo 'ERROR: File does not exist or is not accessable. Input variable: INPUT_KEYFILE_PATH'
    VAR_EXIT=true
  fi
  INPUT_KEYFILE_PATH=$(sanitize_filename "$INPUT_KEYFILE_PATH")
  
  if test -z "$INPUT_HASH_ALGO"
  then
    INPUT_HASH_ALGO=sha512
  fi
}

check_error_exit ()
{
  if test "$VAR_EXIT" = true
  then
    echo 'Exiting.'
    exit 1
  fi
}

VAR_EXIT=false
check_input
check_error_exit
run_task
