#!/bin/sh

# Copyright 2018 by Gero Treuner <gero@70t.de>
#
# This file is part of CAcert key/certificate management scripts (short
# form: "CAcert scripts").
#
# CAcert scripts are free software: You can redistribute it and/or
# modify it under the terms of the GNU Affero General Public License as
# published by the Free Software Foundation, either version 3 of the
# license, or (at your option) any later version.
#
# CAcert scripts are distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public
# License along with CAcert scripts.  If not, see
# <http://www.gnu.org/licenses/>.

# WF_TITLE: Create client certificate including key (PKCS12 format)

# WF_INPUT: INPUT_KEYFILE_PATH      Path of the generated key file
# WF_INPUT: INPUT_CERTFILE_PATH     Path of the certificate file

# WF_OUTPUT: OUTPUT_PKCS12FILE_PATH Path of the PKCS12 file

. "$CONTROL_SCRIPT_DIR/scripts/lib.sh"

set -e

secure_stty

run_task ()
{
  cat <<'ENDMSG'
  
Multiple inputs of a passphrase are required:

  1. Unlock the key (from the file generated in the first task)
    -----
  2. Set a passphrase for the new certifcate file
  3. Repeat (confirm) the passphrase from 2. above

Input area (sequence of 3 passphrases):
ENDMSG
  stty -echo
  $LOCAL outFileName="${INPUT_KEYFILE_PATH%.*}.pfx"

  while ! openssl pkcs12 \
    -export \
    -out "$outFileName" \
    -passin stdin \
    -in "$INPUT_CERTFILE_PATH" \
    -inkey "$INPUT_KEYFILE_PATH"
  do
    echo
    echo 'This did not work. Repeat input (sequence of 3 passphrases):'
  done
  echo
  restore_stty
  echo >"$CONTROL_TEMP_DIR/result" "OUTPUT_PKCS12FILE_PATH='$outFileName'"
  exit $retval
}

check_input ()
{
  if test -z "$INPUT_KEYFILE_PATH"
  then
    echo 'ERROR: No filename given. Input variable: INPUT_KEYFILE_PATH'
    VAR_EXIT=true
  fi
  if ! test -r "$INPUT_KEYFILE_PATH"
  then
    echo 'ERROR: File does not exist or is not accessable. Input variable: INPUT_KEYFILE_PATH'
    VAR_EXIT=true
  fi
  INPUT_KEYFILE_PATH=$(sanitize_filename "$INPUT_KEYFILE_PATH")
  
  if test -z "$INPUT_CERTFILE_PATH"
  then
    echo 'ERROR: No filename given. Input variable: INPUT_CERTFILE_PATH'
    VAR_EXIT=true
  fi
  if ! test -r "$INPUT_CERTFILE_PATH"
  then
    echo 'ERROR: File does not exist or is not accessable. Input variable: INPUT_CERTFILE_PATH'
    VAR_EXIT=true
  fi
  INPUT_CERTFILE_PATH=$(sanitize_filename "$INPUT_CERTFILE_PATH")
}

check_error_exit ()
{
  if test "$VAR_EXIT" = true
  then
    echo 'Exiting.'
    exit 1
  fi
}

VAR_EXIT=false
check_input
check_error_exit
run_task
