#!/bin/sh

# Copyright 2018 by Gero Treuner <gero@70t.de>
#
# This file is part of CAcert key/certificate management scripts (short
# form: "CAcert scripts").
#
# CAcert scripts are free software: You can redistribute it and/or
# modify it under the terms of the GNU Affero General Public License as
# published by the Free Software Foundation, either version 3 of the
# license, or (at your option) any later version.
#
# CAcert scripts are distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public
# License along with CAcert scripts.  If not, see
# <http://www.gnu.org/licenses/>.

# WF_TITLE: Generate a RSA private/public key pair with certificate signing request (CSR)

# WF_INPUT: INPUT_KEY_LENGTH       Length of RSA key (default: 4096)
# WF_INPUT: INPUT_KEYFILE_BASENAME Basename for the generated key file

# WF_OUTPUT: OUTPUT_KEYFILE_PATH   Path of the key file
# WF_OUTPUT: OUTPUT_CSRFILE_PATH   Path of the CSR file

set -e

. "$CONTROL_SCRIPT_DIR/scripts/lib.sh"

secure_stty

run_task ()
{
  echo
  echo "Input of passphrase to protect the generated key is required."
  echo -n "Passphrase (keystrokes are not displayed): "
  stty -echo
  $LOCAL outKeyFileName="${INPUT_KEYFILE_BASENAME}.key"
  $LOCAL outCsrFileName="${INPUT_KEYFILE_BASENAME}.req"
  openssl req \
    -newkey rsa:$INPUT_KEY_LENGTH \
    -batch \
    -passout stdin \
    -keyout "$outKeyFileName" \
    -out "$outCsrFileName"
  $LOCAL retval=$?
  echo
  restore_stty
  outKeyFileName=$(realpath "$outKeyFileName")
  outCsrFileName=$(realpath "$outCsrFileName")
  if test $retval = 0
  then
    echo >"$CONTROL_TEMP_DIR/result" "OUTPUT_KEYFILE_PATH='$outKeyFileName'"
    echo >>"$CONTROL_TEMP_DIR/result" "OUTPUT_CSRFILE_PATH='$outCsrFileName'"
  fi
  exit $retval
}

check_input ()
{
  if test -z "$INPUT_KEYFILE_BASENAME"
  then
    echo 'ERROR: No filename given. Input variable: INPUT_KEYFILE_BASENAME'
    VAR_EXIT=true
  fi
  INPUT_KEYFILE_BASENAME=$(sanitize_filename "$INPUT_KEYFILE_BASENAME")
  
  if test -z "$INPUT_KEY_LENGTH"
  then
    INPUT_KEY_LENGTH=4096
  fi
}

check_error_exit ()
{
  if test "$VAR_EXIT" = true
  then
    echo 'Exiting.'
    exit 1
  fi
}

VAR_EXIT=false
check_input
check_error_exit
run_task
