#!/bin/sh

# Copyright 2018 by Gero Treuner <gero@70t.de>
#
# This file is part of CAcert key/certificate management scripts (short
# form: "CAcert scripts").
#
# CAcert scripts are free software: You can redistribute it and/or
# modify it under the terms of the GNU Affero General Public License as
# published by the Free Software Foundation, either version 3 of the
# license, or (at your option) any later version.
#
# CAcert scripts are distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public
# License along with CAcert scripts.  If not, see
# <http://www.gnu.org/licenses/>.

# WF_TITLE: Install certificate in web browser (application)

# WF_INPUT: INPUT_BROWSER_PATH Path of the web browser
# WF_INPUT: INPUT_PKCS12FILE_PATH Path of the PKCS12 file

set -e

. "$CONTROL_SCRIPT_DIR/scripts/lib.sh"

run_task ()
{
  cat <<'ENDMSG'

For authenticating with the certificate import in the web browsers is required.


Usual Steps

   1. Confirm that you want to open the file (extension *.pfx)
   2. Confirm that you want to import the file as certificate.
   3. Unlock the contained private key by entering the passphrase.

Notes

   Not all browsers show these dialogs and confirmations.
   For details refer to the browser's manuals and help pages.


If ready, press enter to open the certificate with the browser for import.
ENDMSG
  $LOCAL answer
  read answer
  nohup "$INPUT_BROWSER_PATH" "file://$INPUT_PKCS12FILE_PATH" >/dev/null 2>&1 &

  cat <<'ENDMSG'
-------------------------------------------------------------------------------

Congratulations - now you are ready for secure communication:

   1. Let senders transmit emails encrypted using your certificate.
   2. Sign emails.
   3. Authenticate to services without password.


If you want to try to authenticate passwordless to CAcert now, enter "y".
ENDMSG
  echo -n "Choice: "
  read answer
  if test "$answer" = "y"
  then
    nohup "$INPUT_BROWSER_PATH" "https://secure.cacert.org/index.php?id=4" >/dev/null 2>&1 &
  fi

  exit 0
}

check_input ()
{
  if test -z "$INPUT_BROWSER_PATH"
  then
    echo 'ERROR: No filename given. Input variable: INPUT_BROWSER_PATH'
    VAR_EXIT=true
  fi
  if ! test -x "$INPUT_BROWSER_PATH"
  then
    echo 'ERROR: File does not exist or is not executable. Input variable: INPUT_BROWSER_PATH'
    VAR_EXIT=true
  fi
  INPUT_BROWSER_PATH=$(sanitize_filename "$INPUT_BROWSER_PATH")

  if test -z "$INPUT_PKCS12FILE_PATH"
  then
    echo 'ERROR: No filename given. Input variable: INPUT_PKCS12FILE_PATH'
    VAR_EXIT=true
  fi
  if ! test -r "$INPUT_PKCS12FILE_PATH"
  then
    echo 'ERROR: File does not exist or is not accessable. Input variable: INPUT_PKCS12FILE_PATH'
    VAR_EXIT=true
  fi
  INPUT_PKCS12FILE_PATH=$(sanitize_filename "$INPUT_PKCS12FILE_PATH")
}

check_error_exit ()
{
  if test "$VAR_EXIT" = true
  then
    echo 'Exiting.'
    exit 1
  fi
}

VAR_EXIT=false
check_input
check_error_exit
run_task
