#!/bin/sh

# Copyright 2018 by Gero Treuner <gero@70t.de>
#
# This file is part of CAcert key/certificate management scripts (short
# form: "CAcert scripts").
#
# CAcert scripts are free software: You can redistribute it and/or
# modify it under the terms of the GNU Affero General Public License as
# published by the Free Software Foundation, either version 3 of the
# license, or (at your option) any later version.
#
# CAcert scripts are distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public
# License along with CAcert scripts.  If not, see
# <http://www.gnu.org/licenses/>.

# WF_TITLE: Get certificate from CAcert by uploading the CSR (certificate signing request)

# WF_INPUT: INPUT_BROWSER_PATH Path of the web browser
# WF_INPUT: INPUT_CSRFILE_PATH Path of the CSR file

# WF_OUTPUT: OUTPUT_CERTFILE_PATH   Path of the certificate file

set -e

. "$CONTROL_SCRIPT_DIR/scripts/lib.sh"

run_task ()
{
  cat <<'ENDMSG'

Uploading and processing the CSR at CAcert is required.


Prerequisits

   1. You are member of the CAcert community with the logon credentials ready.
   2. Your browser is prepared to trust the CAcert root certificates.

Notes ad 2.

   Trusted roots enable a secure connection to protect your credentials and
   data.  You can find the CAcert root certificates at these places:
     www.cacert.org/index.php?id=3
   In case of problems try this certificate (also contained in this package):
     svn.cacert.org/CAcert/SystemAdministration/signer/re-sign-2016/outputs/root_256.crt
   You should grant trust as root certification authority for authentication
   of servers and email senders - for details refer to your browser's manual.


If ready, press enter to open the CAcert site and see the instructions.
ENDMSG
  $LOCAL answer
  read answer
  nohup "$INPUT_BROWSER_PATH" https://www.cacert.org >/dev/null 2>&1 &

  cat <<'ENDMSG'
-------------------------------------------------------------------------------

Processing Steps

   1. Switch to your browser at CAcert (link www.cacert.org ).
   2. Menu "My Account" on the right: Choose a logon method and proceed
   3. Menu "Client Certificates -> New" on the right
   
   Now you should see the form "New Client Certificate".

   4. Choose among emails and name to include.
   5. Tick "Show advanced options".
   6. Choose SHA-512 as hash algorithm for best security.
   7. Paste the contents of the file below in the field
      "Optional Client CSR":

ENDMSG
  echo "   $INPUT_CSRFILE_PATH"
  cat <<'ENDMSG'

   8. Press "Next" when the form is completed.

   Now you should see a successful result with the certificate download offer.


If ready, press enter to proceed with downloading.
ENDMSG
  read answer

  cat <<'ENDMSG'
-------------------------------------------------------------------------------

Download Steps

   1. Download the certificate to your local computer.
   2. Enter the path of the downloaded certificate below.

Notes

   Filename:          This usually is in the format <your@email>.cer .
   Directory:         Often your download directory is $HOME/Downloads
   Import to browser: This will fail, because the certificate is missing the
                      private key. We'll put it together in the next step ...


(Full) path of the downloaded certificate file:
ENDMSG
  read answer

  while ! test -r "$answer"
  do
    echo
    echo "This is not a valid file. Please enter again."
    echo "(Full) path of the downloaded certificate file:"
    read answer
  done

  answer=$(realpath "$answer")
  echo >"$CONTROL_TEMP_DIR/result" "OUTPUT_CERTFILE_PATH='$answer'"
  exit 0
}

check_input ()
{
  if test -z "$INPUT_BROWSER_PATH"
  then
    echo 'ERROR: No filename given. Input variable: INPUT_BROWSER_PATH'
    VAR_EXIT=true
  fi
  if ! test -x "$INPUT_BROWSER_PATH"
  then
    echo 'ERROR: File does not exist or is not executable. Input variable: INPUT_BROWSER_PATH'
    VAR_EXIT=true
  fi
  INPUT_BROWSER_PATH=$(sanitize_filename "$INPUT_BROWSER_PATH")

  if test -z "$INPUT_CSRFILE_PATH"
  then
    echo 'ERROR: No filename given. Input variable: INPUT_CSRFILE_PATH'
    VAR_EXIT=true
  fi
  if ! test -r "$INPUT_CSRFILE_PATH"
  then
    echo 'ERROR: File does not exist or is not accessable. Input variable: INPUT_CSRFILE_PATH'
    VAR_EXIT=true
  fi
  INPUT_CSRFILE_PATH=$(sanitize_filename "$INPUT_CSRFILE_PATH")
}

check_error_exit ()
{
  if test "$VAR_EXIT" = true
  then
    echo 'Exiting.'
    exit 1
  fi
}

VAR_EXIT=false
check_input
check_error_exit
run_task
