#!/bin/sh

# Copyright 2018 by Gero Treuner <gero@70t.de>
#
# This file is part of CAcert key/certificate management scripts (short
# form: "CAcert scripts").
#
# CAcert scripts are free software: You can redistribute it and/or
# modify it under the terms of the GNU Affero General Public License as
# published by the Free Software Foundation, either version 3 of the
# license, or (at your option) any later version.
#
# CAcert scripts are distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public
# License along with CAcert scripts.  If not, see
# <http://www.gnu.org/licenses/>.

# WF_TITLE: Select a web browser

# WF_OUTPUT: OUTPUT_BROWSER_PATH Path of the web browser

set -e

. "$CONTROL_SCRIPT_DIR/scripts/lib.sh"

run_task ()
{
  VAR_BROWSER=
  while ! test -x "$VAR_BROWSER"
  do
    run_menu
  done
  echo >"$CONTROL_TEMP_DIR/result" "OUTPUT_BROWSER_PATH='$VAR_BROWSER'"
}

run_menu ()
{
  echo
  echo "You need to choose a web browser. We found these:"
  echo

  $LOCAL i=1
  for b in sensible-browser google-chrome firefox chromium
  do
    $LOCAL path=$(which $b)
    if test -x "$path"
    then
      eval X_BROWSER$i=$path
      echo "   $i - $path"
      i=$((i + 1))
    fi
  done

  echo
  echo "Please enter a number from above, or a path to another executable."
  echo -n "Choice: "
  read i
  if echo "$i" | grep -q '^[0-9][0-9]*$'
  then
    eval "VAR_BROWSER=\${X_BROWSER$i}" 2>/dev/null
  else
    VAR_BROWSER=
  fi
  if test -z "$VAR_BROWSER"
  then
    if test -x "$i"
    then
      VAR_BROWSER="$i"
    else
      echo "ERROR: The file does not exist or is not executable. Path: $i"
    fi
  fi
}

check_error_exit ()
{
  if test "$WF_EXIT" = true
  then
    echo 'Exiting.'
    exit 1
  fi
}

VAR_EXIT=false
run_task
